# gank
## Install
pip install gank
## Usage
### hump()
`print(hump('name_of_value'))`
### uline()
`print(uline('nameOfValue'))`
### llist()
```
s='''
abc def ghi
jkl mno pqr
stu vwx yz
'''
print(llist(ss))
```